compare_models: Compare some performance measures of models fitted to your...

Description Usage Arguments Value Examples

View source: R/compare_models.R

Description

Compare some performance measures of models fitted to your data.

Usage

1
compare_models(data, eqn, models = c("logreg"), outputs = c("fitted_values"))

Arguments

data

data.frame containing at least the response and all explanatory variables in your equation

eqn

string specifying the formula for the models to fit

models

vector/list of the names of models (as strings) to compare - currently supports logistic regression (logreg)

outputs

vector/list specifying, as strings, the types of outputs that should be returned - currently supports the fitted/predicted values for the data given, calculated with the model fitted (fitted_values)

Value

Returns a data.frame with a row for each model fitted and columns for each output requested.

Examples

1
compare_models(data = gapminder::gapminder, eqn = "lifeExp ~ gdpPercap", models = c('logreg'))

hantonita/model.comp documentation built on Jan. 1, 2021, 3:15 a.m.